==> 2.5.zip: piwigo/language/ta_IN/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Only administrator can run upgrade: please sign in below.'] = 'ஒரு நிர்வாகி மட்டும் தான் ஒரு மேம்படுத்தலை இயக்க முடியும்: கீழே நுழையுங்கள்.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'ஒரே சிறுபடங்களை முன்னொட்டு மற்றும் வலை மேலாளரின் மின்னஞ்சல் முகவரி முந்தைய கட்டமைப்பு இருந்து சேமிக்கப்பட்டது';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'ஒரு பராமரிப்பு சரிபார்ப்பு செய்யவும் [நிர்வாக> கருவிகள்> பராமரிப்பு] இல் உங்களுக்கு எந்த சிக்கல்களை தீர்க்க';
$lang['SQL queries'] = 'SQL வினவல்கள்';
$lang['Statistics'] = 'புள்ளி விவரம்';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'இந்த பக்கம் உங்கள் பழைய Piwigo பதிப்பு புதிய பதிப்பு தகவல் மேம்படுத்த முன்மொழிகிறது.மேம்படுத்தல் உதவி நினைக்கிறது
உங்களுக்கு தற்போது <strong> வெளியீடு %s </strong> (அல்லது அதற்கு சமமான) இயங்குகிறது.';
$lang['Upgrade informations'] = 'தகவலை மேம்படுத்தல்';
$lang['Upgrade from version %s to %s'] = 'பதிப்பு% s இலிருந்து% s மேம்படுத்தல்';
$lang['Upgrade'] = 'மேம்படுத்தல்';
$lang['User permissions and group permissions have been erased'] = 'பயனர்கள் மற்றும் குழுக்களின் அனுமதிகள் நீக்கப்பட்டன';
$lang['You do not have access rights to run upgrade'] = 'நீங்கள் மேம்படுத்தலை இயக்க சரியான அணுகல் இல்லை';
$lang['total SQL time'] = 'மொத்த SQL நேரம்';
$lang['total upgrade time'] = 'மொத்த மேம்படுத்தல் நேரம்';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'இல் <i>%s</i>, முன்பாக <b>?></b>, முன்பாக:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'ஒரு முன்னெச்சரிக்கையாக, பின்வரும் கருப்பொருள்கள் முடக்கப்பட்டிருக்கிறது. நீங்கள்  கண்டிப்பாக மேம்படுத்த கருப்பொருள்களை சரிபார்க்க வேண்டும் முன்பாக மறு செயலாக்க';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'ஒரு முன்னெச்சரிக்கையாக, பின்வரும் செருகுநிரல்கள் முடக்கப்பட்டிருக்கிறது.நீங்கள் அவற்றை மேம்படுத்த செயலாக்க மீண்டும் செருகுநிரல்களை செயலாக்க வேண்டும்
';
$lang['All sub-albums of private albums become private'] = 'அனைத்து துணை ஆல்பங்களின்
தனியார் ஆல்பங்கள் தனியார் ஆக இருந்து';
?>

==> 14.5.0.zip: piwigo/language/ta_IN/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['Only administrator can run upgrade: please sign in below.'] = 'ஒரு நிர்வாகி மட்டும் தான் ஒரு மேம்படுத்தலை இயக்க முடியும்: கீழே நுழையுங்கள்.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'ஒரே சிறுபடங்களை முன்னொட்டு மற்றும் வலை மேலாளரின் மின்னஞ்சல் முகவரி முந்தைய கட்டமைப்பு இருந்து சேமிக்கப்பட்டது';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'ஒரு பராமரிப்பு சரிபார்ப்பு செய்யவும் [நிர்வாக> கருவிகள்> பராமரிப்பு] இல் உங்களுக்கு எந்த சிக்கல்களை தீர்க்க';
$lang['SQL queries'] = 'SQL வினவல்கள்';
$lang['Statistics'] = 'புள்ளி விவரம்';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'இந்த பக்கம் உங்கள் பழைய Piwigo பதிப்பு புதிய பதிப்பு தகவல் மேம்படுத்த முன்மொழிகிறது.மேம்படுத்தல் உதவி நினைக்கிறது
உங்களுக்கு தற்போது <strong> வெளியீடு %s </strong> (அல்லது அதற்கு சமமான) இயங்குகிறது.';
$lang['Upgrade informations'] = 'தகவலை மேம்படுத்தல்';
$lang['Upgrade from version %s to %s'] = 'பதிப்பு% s இலிருந்து% s மேம்படுத்தல்';
$lang['Upgrade'] = 'மேம்படுத்தல்';
$lang['User permissions and group permissions have been erased'] = 'பயனர்கள் மற்றும் குழுக்களின் அனுமதிகள் நீக்கப்பட்டன';
$lang['You do not have access rights to run upgrade'] = 'நீங்கள் மேம்படுத்தலை இயக்க சரியான அணுகல் இல்லை';
$lang['total SQL time'] = 'மொத்த SQL நேரம்';
$lang['total upgrade time'] = 'மொத்த மேம்படுத்தல் நேரம்';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'இல் <i>%s</i>, முன்பாக <b>?></b>, முன்பாக:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'ஒரு முன்னெச்சரிக்கையாக, பின்வரும் கருப்பொருள்கள் முடக்கப்பட்டிருக்கிறது. நீங்கள்  கண்டிப்பாக மேம்படுத்த கருப்பொருள்களை சரிபார்க்க வேண்டும் முன்பாக மறு செயலாக்க';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'ஒரு முன்னெச்சரிக்கையாக, பின்வரும் செருகுநிரல்கள் முடக்கப்பட்டிருக்கிறது.நீங்கள் அவற்றை மேம்படுத்த செயலாக்க மீண்டும் செருகுநிரல்களை செயலாக்க வேண்டும்
';
$lang['All sub-albums of private albums become private'] = 'அனைத்து துணை ஆல்பங்களின்
தனியார் ஆல்பங்கள் தனியார் ஆக இருந்து';
?>
